@@ -14,7 +14,7 @@ use AutoLoader qw(AUTOLOAD);
 
 @ISA = qw(Exporter DynaLoader);
 
-$VERSION = do { my @r = (q$Revision: 0.47 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.48 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @EXPORT_OK = qw(
 	get1char
@@ -730,7 +730,7 @@ Compress a domain name and append it to the buffer.
 
 	  i.e.	initial call
 
-  ($newoff,@dnptrs)=dn_comp(\$name,\$buffer,$offset);
+  ($newoff,@dnptrs)=dn_comp(\$buffer,$offset,\$name);
 
 	   2) if \@dnptrs is null, no compression takes place
 
@@ -1097,7 +1097,7 @@ dn_expand is from Michael Fuhr's Net::DNS package (DNS.pm), copyright (c)
 
 =head1 COPYRIGHT
 
-    Copyright 2003 - 2011, Michael Robinton <michael@bizsystems.com>
+    Copyright 2003 - 2014, Michael Robinton <michael@bizsystems.com>
    
 Michael Robinton <michael@bizsystems.com>
 
